@@ -1,5 +1,5 @@
 package Mojo::Weixin;
-our $VERSION = '1.2.6';
+our $VERSION = '1.2.7';
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
 use Mojo::IOLoop;
 use Mojo::Weixin::Log;
@@ -68,6 +68,7 @@ has ua_request_timeout      => 35;
 has ua_inactivity_timeout   => 35;
 has is_first_login          => -1;
 has login_state             => 'init';
+has qrcode_upload_url       => undef;
 has qrcode_count            => 0;
 has qrcode_count_max        => 10;
 has media_size_max          => sub{20 * 1024 * 1024}; #运行上传的最大文件大小
@@ -211,10 +212,13 @@ sub new {
     $SIG{INT}  = $SIG{TERM} = $SIG{HUP} = sub{
         return if $^O ne 'MSWin32' and $_[0] eq 'INT' and !-t;
         $self->info("捕获到停止信号[$_[0]]，准备停止...");
-        $self->clean_qrcode();
-        $self->clean_pid();
         $self->stop();
     };
+    $self->on(stop=>sub{
+        my $self = shift;
+        $self->clean_qrcode();
+        $self->clean_pid();
+    });
     $self->on(state_change=>sub{
         my $self = shift;
         $self->save_state();
