@@ -1,7 +1,5 @@
 package Mojo::Weixin::Controller;
 use strict;
-use warnings;
-use Carp;
 use Config;
 use File::Spec;
 use Mojo::Weixin::Base 'Mojo::EventEmitter';
@@ -39,9 +37,15 @@ has ua_debug_req_body   => sub{$_[0]->ua_debug};
 has ua_debug_res_body   => sub{$_[0]->ua_debug};
 has ua_retry_times          => 5;
 has ua_connect_timeout      => 10;
-has ua_request_timeout      => 35;
-has ua_inactivity_timeout   => 35;
-has ua  => sub {Mojo::UserAgent->new(connect_timeout=>3,inactivity_timeout=>3,request_timeout=>3)};
+has ua_request_timeout      => 120;
+has ua_inactivity_timeout   => 120;
+has ua  => sub {
+    Mojo::UserAgent->new(
+        connect_timeout=>$_[0]->ua_connect_timeout,
+        request_timeout=>$_[0]->ua_request_timeout,
+        inactivity_timeout=>$_[0]->ua_inactivity_timeout,
+    )
+};
 
 has tmpdir              => sub {File::Spec->tmpdir();};
 has pid_path            => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_process','.pid'))};
@@ -49,39 +53,23 @@ has backend_path        => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_
 has template_path        => sub {File::Spec->catfile($_[0]->tmpdir,join('','mojo_weixin_controller_template','.pl'))};
 has check_interval      => 5;
 
-has log_level           => 'info';     #debug|info|warn|error|fatal
+has log_level           => 'info';     #debug|info|msg|warn|error|fatal
 has log_path            => undef;
 has log_encoding        => undef;      #utf8|gbk|...
 has log_head            => "[wxc][$$]";
 has log_console         => 1;
+has disable_color       => 0;
 
 has version             => sub{$Mojo::Weixin::Controller::VERSION};
 
 has log     => sub{
-    my $self = $_[0];
     Mojo::Weixin::Log->new(
         encoding    =>  $_[0]->log_encoding,
         path        =>  $_[0]->log_path,
         level       =>  $_[0]->log_level,
-        console_output => $_[0]->log_console,
-        format      =>  sub{
-            my ($time, $level, @lines) = @_;
-            my $title = "";
-            my $head  = $self->log_head || "";
-            if(ref $lines[0] eq "HASH"){
-                my $opt = shift @lines; 
-                $time = $opt->{"time"} if defined $opt->{"time"};
-                $title = $opt->{"title"} . " " if defined $opt->{"title"};
-                $level  = $opt->{"level"} if defined $opt->{"level"};
-                $head  = $opt->{"head"} if defined $opt->{"head"};
-            }
-            @lines = split /\n/,join "",@lines;
-            my $return = "";
-            $time = $time?POSIX::strftime('[%y/%m/%d %H:%M:%S]',localtime($time)):"";
-            $level = $level?"[$level]":"";
-            for(@lines){$return .= $head . $time . " " . $level . " " . $title . $_ . "\n";}
-            return $return;
-        }
+        head        =>  $_[0]->log_head,
+        disable_color   => $_[0]->disable_color,
+        console_output  => $_[0]->log_console,
     )
 };
 sub new {
@@ -235,7 +223,6 @@ sub start_client {
         $poll_api =  $url->to_string;
     }
     $param->{account} = $param->{client};
-    $self->reform_hash($param);
 
     for my $env(keys %ENV){
         delete $ENV{$env} if $env=~/^MOJO_WEIXIN_([A-Z_]+)$/;
@@ -381,18 +368,41 @@ sub run {
     $self->ioloop->start if not $self->ioloop->is_running;
 }
 
+package Mojo::Weixin::Controller::App::Controller;
+use Mojo::JSON ();
+use Mojo::Util ();
+use base qw(Mojolicious::Controller);
+sub render{
+    my $self = shift;
+    if($_[0] eq 'json'){
+        $self->res->headers->content_type('application/json');
+        $self->SUPER::render(data=>Mojo::JSON::to_json($_[1]),@_[2..$#_]);
+    }
+    else{$self->SUPER::render(@_)}
+}
+sub safe_render{
+    my $self = shift;
+    $self->render(@_) if (defined $self->tx and !$self->tx->is_finished);
+}
+sub param{
+    my $self = shift;
+    my $data = $self->SUPER::param(@_);
+    defined $data?Mojo::Util::encode("utf8",$data):undef;
+}
+sub params {
+    my $self = shift;
+    my $hash = $self->req->params->to_hash ;
+    $self->stash('wxc')->reform($hash);
+    return $hash;
+}
 package Mojo::Weixin::Controller::App;
 use Mojolicious::Lite;
 use Mojo::Transaction::HTTP;
-helper safe_render =>sub {
-    my $c = shift;
-    $c->render(@_) if (defined $c->tx and !$c->tx->is_finished);
-};
+app->controller_class('Mojo::Weixin::Controller::App::Controller');
 under sub {
     my $c = shift;
     if(ref $c->stash('wxc')->auth eq "CODE"){
-        my $hash  = $c->req->params->to_hash;
-        $c->stash('wxc')->reform_hash($hash);
+        my $hash  = $c->params;
         my $ret = 0;
         eval{
             $ret = $c->stash('wxc')->auth->($hash,$c);
@@ -405,13 +415,13 @@ under sub {
 };
 get '/openwx/start_client' => sub{
     my $c = shift;
-    my $hash   = $c->req->params->to_hash;
+    my $hash   = $c->params;
     my $result =  $c->stash('wxc')->start_client($hash);
     $c->safe_render(json=>$result);
 };
 get '/openwx/stop_client' => sub{
     my $c = shift;
-    my $hash   = $c->req->params->to_hash;
+    my $hash   = $c->params;
     my $result = $c->stash('wxc')->stop_client($hash);
     $c->safe_render(json=>$result);
 };
@@ -465,7 +475,7 @@ get '/openwx/check_client' => sub{
             my @client;
             for my $client ( values %{ $c->stash('wxc')->backend }){
                 my $state_path = $client->{_state_path};
-                my $json = $c->stash('wxc')->decode_json($c->stash('wxc')->slurp($state_path));
+                my $json = $c->stash('wxc')->from_json($c->stash('wxc')->slurp($state_path));
                 $json->{port} = $client->{port};
                 push @client,$json;
             }
@@ -489,6 +499,7 @@ any '/openwx/*whatever'  => sub{
         $c->safe_render(json => {code => 1, status=>'client not exists',});
         return;
     }
+    $c->inactivity_timeout(120);
     $c->render_later;
     my $tx = Mojo::Transaction::HTTP->new(req=>$c->req->clone);
     $tx->req->url->host("127.0.0.1");
@@ -496,7 +507,7 @@ any '/openwx/*whatever'  => sub{
     $tx->req->url->scheme('http');
     $tx->req->headers->header('Host',$tx->req->url->host_port);
     return if $c->stash('mojo.finished');
-    $c->ua->start($tx,sub{
+    $c->stash('wxc')->ua->start($tx,sub{
         my ($ua,$tx) = @_;
         $c->tx->res($tx->res);
         $c->rendered;
